@@ -10,16 +10,15 @@ package Devel::Cover::DB::IO;
 use strict;
 use warnings;
 
-our $VERSION = '0.86'; # VERSION
+our $VERSION = '0.87'; # VERSION
 
 my $Format;
 
 BEGIN
 {
-    $Format = "JSON"     if eval "use JSON; 1";
-    # warn "JSON available\n" if $INC{"JSON.pm"};
+    $Format = "JSON"     if              eval "use JSON; 1";
+    $Format = "JSON"     if !$Format and eval "use JSON:PP; 1";
     $Format = "Storable" if !$Format and eval "use Storable; 1";
-    # warn "Storable available\n" if $INC{"Storable.pm"};
     die "Can't load either JSON or Storable" unless $Format;
 }
 
@@ -47,7 +46,7 @@ Devel::Cover::DB::IO - IO routines for Devel::Cover::DB
 
 =head1 VERSION
 
-version 0.86
+version 0.87
 
 =head1 SYNOPSIS
 
