@@ -11,9 +11,17 @@ use strict;
 use warnings;
 
 use Fcntl ":flock";
-use JSON;
 
-our $VERSION = '0.86'; # VERSION
+our $VERSION = '0.87'; # VERSION
+
+my $Format;
+
+BEGIN
+{
+    $Format = "JSON"     if              eval "use JSON; 1";
+    $Format = "JSON::PP" if !$Format and eval "use JSON::PP; 1";
+    die "Can't load either JSON or JSON::PP" unless $Format;
+}
 
 sub new
 {
@@ -30,7 +38,9 @@ sub read
     open my $fh, "<", $file or die "Can't open $file: $!";
     flock($fh, LOCK_SH) or die "Cannot lock file: $!\n";
     local $/;
-    my $data = JSON::decode_json(<$fh>);
+    my $data = $Format eq "JSON"
+        ? JSON::decode_json(<$fh>)
+        : JSON::PP::decode_json(<$fh>);
     close $fh or die "Can't close $file: $!";
     $data
 }
@@ -40,7 +50,8 @@ sub write
     my $self = shift;
     my ($data, $file) = @_;
 
-    my $json = JSON->new->utf8->allow_blessed;
+    my $json = $Format eq "JSON" ? JSON->new : JSON::PP->new;
+    $json->utf8->allow_blessed;
     $json->ascii->pretty->canonical if $self->{options} =~ /\bpretty\b/i;
     open my $fh, ">", $file or die "Can't open $file: $!";
     flock($fh, LOCK_EX) or die "Cannot lock file: $!\n";
@@ -59,7 +70,7 @@ Devel::Cover::DB::IO::JSON - JSON based IO routines for Devel::Cover::DB
 
 =head1 VERSION
 
-version 0.86
+version 0.87
 
 =head1 SYNOPSIS
 
