@@ -7,7 +7,7 @@ use Getopt::Long;
 use Devel::Cover::DB;
 use Devel::Cover::Truth_Table;
 
-our $VERSION = '0.86'; # VERSION
+our $VERSION = '0.87'; # VERSION
 our $LVERSION = do { eval '$VERSION' || "0.001" };  # for development purposes
 
 #-------------------------------------------------------------------------------
@@ -214,7 +214,7 @@ sub _branch_report {
 #-------------------------------------------------------------------------------
 sub _condition_report {
     my $coverage = shift;
-    # use Data::Dumper; print STDERR Dumper $coverage;
+    # use Devel::Cover::Dumper; print STDERR Dumper $coverage;
 
     my @tables = truth_table(@{$coverage->{condition}});
     return unless @tables;
@@ -360,6 +360,7 @@ sub print_summary_report {
     push @$show, 'total';
 
     print_html_header($fh, $options->{option}{summarytitle});
+    # TODO - >= 100% doesn't look nice.  See also Html_basic.
     print $fh <<"END_HTML";
 <body>
 <h1>$options->{option}{summarytitle}</h1>
@@ -740,15 +741,13 @@ sub report {
 
 =head1 VERSION
 
-version 0.86
+version 0.87
 Devel::Cover::Report::Html_minimal - Backend for HTML reporting of coverage
 statistics
 
 =head1 SYNOPSIS
 
- use Devel::Cover::Report::Html_minimal;
-
- Devel::Cover::Report::Html_minimal->report($db, $options);
+ cover -report html_minimal
 
 =head1 DESCRIPTION
 
@@ -773,26 +772,26 @@ directory.
 
 =item pod
 
-Includes POD (and blank lines) in the file report. This is on by default.  It
+Includes POD (and blank lines) in the file report.  This is on by default.  It
 may be turned off with -nopod.
 
 =item data
 
-Includes text after the C<__DATA__> or C<__END__> tokens in the file report. By
+Includes text after the C<__DATA__> or C<__END__> tokens in the file report.  By
 default, this text is trimmed.
 
 Note: If your POD is after an C<__END__>, you have to specify 'data' to include
-it, not 'pod'. The 'pod' option only applies to POD before the C<__END__>.
+it, not 'pod'.  The 'pod' option only applies to POD before the C<__END__>.
 
 =item unified
 
-Generates a "unified" report for each file. The detailed data that normally
-appears in the auxilliary reports (branch, condition, etc.) is placed in the
-file report, and the auxilliarry reports are not generated.
+Generates a "unified" report for each file.  The detailed data that normally
+appears in the auxiliary reports (branch, condition, etc.) are placed in the
+file report, and the auxiliary reports are not generated.
 
 =item summarytitle
 
-Specify the tile of the summary.  The default is "Coverage Summary".
+Specify the title of the summary.  The default is "Coverage Summary".
 
 =back
 
